/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2009 Canonical Services Ltd (www.canonical.com)
 *               2009 Mikkel Kamstrup Erlandsen
 *
 * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
 *          Mikkel Kamstrup Erlandsen <mikkel.kamstrup@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of version 2 of the GNU Lesser General Public
 * License as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
 
#ifndef __COUCHDB_GLIB_H__
#define __COUCHDB_GLIB_H__

#include <couchdb-types.h>
#include <couchdb-array-field.h>
#include <couchdb-credentials.h>
#include <couchdb-database-info.h>
#include <couchdb-database.h>
#include <couchdb-design-document.h>
#include <couchdb-document.h>
#include <couchdb-document-contact.h>
#include <couchdb-document-info.h>
#include <couchdb-document-task.h>
#include <couchdb-query.h>
#include <couchdb-response.h>
#include <couchdb-session.h>
#include <couchdb-struct-field.h>

#endif /* __COUCHDB_GLIB_H__ */


